Skip to contents

The default mapping from logical roles to the column names produced by the upstream packages. Pass a modified copy to link_panel() to adapt to a panel with different column names.

Usage

synthid_cols()

Value

A named list of column names.