Skip to contents

Defaults for the honorifics that a parser may fuse onto a given name and the post-nominal credential tokens that may leak into a surname. Exposed as functions so a caller can extend them (e.g. flag_links(cred = c(credential_tokens(), "RDN"))).

Usage

honorific_tokens()

credential_tokens()

Value

A character vector of upper-case tokens.