Token sets used by the link-review flaggers
synthid_tokens.RdDefaults for the honorifics that a parser may fuse onto a given name and the
post-nominal credential tokens that may leak into a surname. Exposed as
functions so a caller can extend them (e.g. flag_links(cred = c(credential_tokens(), "RDN"))).